@@ -22,7 +22,7 @@
 
 #define CHAR_WIDTH 5
 #define CHAR_HEIGHT 7
-#define VERSION "2.91"
+#define VERSION "2.92"
 #define _MULTI_THREADED
 
 typedef enum {NONE, ALARM, TIMER, TIMER_PAUSED, TIMER_DONE, CHRONO, CHRONO_PAUSED} modeType;
@@ -217,7 +217,12 @@ void parseArgs(int argc, char *argv[])
   {
     char *arg = argv[argIndex];
 
-    if (*arg == '-') 
+    // Allow for the options that wmgeneral.c accepts
+    if (!strcmp(arg, "-color") ||
+	!strcmp(arg, "-display") ||
+	!strcmp(arg, "-geometry")) {
+    }
+    else if (*arg == '-') 
     {
       switch (arg[1]) 
       {
@@ -230,9 +235,9 @@ void parseArgs(int argc, char *argv[])
 	case 'r':
 	  mode = CHRONO;
 	  break;
-  case 'b':
-    action.bell = 1;
-    break;
+	case 'b':
+	  action.bell = 1;
+	  break;
 	case 'e':
 	  strcpy(command, argv[argIndex+1]);
 	  action.command = 1;
@@ -399,7 +404,7 @@ void usage(void)
   fprintf(stderr, "             at specified time\n");
   fprintf(stderr, "    -c     countdowntimer mode, wmtimer will beep/exec\n");
   fprintf(stderr, "	         command when specified time reaches 0 \n");
-  fprintf(stderr, "    -color <color> as a word or as rgb:RR/GG/BB\n");
+  fprintf(stderr, "    --color <color> as a word or as rgb:RR/GG/BB\n");
   fprintf(stderr, "    -b     beep\n");
   fprintf(stderr, "    -e     <command> exec command\n");
   fprintf(stderr, "    -r     start in chronograph mode\n");
